"""
Django-panorama
---------------

Integration of jQuery virtual tour in Django.

One model stores panoramic photo while a number of other models represents
clickable areas in the panorama. Included areas can show HTML block (using
tinymce) or display another url in a iframe.

gisa.buildingmaps integrates with this application giving one extra area to
allow navigating locations (virtual tour experience).
"""
