<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
    <head>
            {% block panorama_css %}
            {% endblock panorama_css %}
            {% block panorama_javascript %}
            {% endblock panorama_javascript %}
    </head>
    <body>
            {% block panorama_title %}
            {% endblock panorama_title %}
            {% block panorama_content %}
            {% endblock panorama_content %}
    </body>
</html>
