{% extends "admin/change_form.html" %}
{% load i18n admin_modify adminmedia %}
{% load panorama_admin %}

{% block object-tools-items %}
  {% panoramainfo_types as pi_types %}
  {% for pi in pi_types %}
      <li><a href="{{pi.url}}?panorama={{original.id}}">Add {{pi.label}}</a></li>
  {% endfor %}
  {{ block.super }}
{% endblock %}
