{% extends "panorama/base.html" %}
{% load panoramas %}

{% block panorama_css %}
<link rel="stylesheet" href="{{STATIC_URL}}panorama/jquery.panorama.css" />
<link rel="stylesheet" href="{{STATIC_URL}}panorama/jquery.fancybox-1.3.4.css" type="text/css" media="screen" />
{% endblock%}

{% block panorama_javascript %}
{% panorama_js %}
{% endblock %}

{% block panorama_title %}
{{panorama.title}}
{% endblock %}


{% block panorama_content %}
{% show_panorama panorama %}
{% endblock panorama_content %}
