{% extends "panorama/base.html" %}


{% block panorama_title %}
List of all panoramas
{% endblock %}


{% block panorama_content %}
<ul>
    {% for panorama in object_list %}
    <li><a href="{{panorama.get_absolute_url}}">{{panorama.title}}</a></li>
    {% endfor %}
</ul>
{% endblock panorama_content %}
